@@ -12,7 +12,7 @@ sub EXPORT {
 
 =head1 NAME
 
-Filesys::POSIX::Userland::Find
+Filesys::POSIX::Userland::Find - Crawl directories in a filesystem
 
 =head1 SYNOPSIS
 
@@ -31,28 +31,28 @@ Filesys::POSIX::Userland::Find
 
 =head1 DESCRIPTION
 
-Filesys::POSIX::Userland::Find provides an extension module to Filesys::POSIX
-that operates very similarly in principle to the Perl Core module
-L<File::Find>, albeit with some minor differences and fewer options.  For the
-sake of efficiency, tail recursion, rather than pure call recursion, is used to
-handle very deep hierarchies.
+This module provides an extension module to L<Filesys::POSIX> that operates
+very similarly in principle to the Perl Core module L<File::Find>, albeit with
+some minor differences and fewer options.  For the sake of efficiency, tail
+recursion, rather than pure call recursion, is used to handle very deep
+hierarchies.
 
 =head1 USAGE
 
 =over
 
-=item $fs->find($callback, @paths)
+=item C<$fs-E<gt>find($callback, @paths)>
 
-=item $fs->find($callback, $options, @paths)
+=item C<$fs-E<gt>find($callback, $options, @paths)>
 
-$fs->find() will perform recursive descent into each path passed, printing the
-full pathname of each item found relative to each item found in the @paths
+C<$fs-E<gt>find> will perform recursive descent into each path passed, printing
+the full pathname of each item found relative to each item found in the @paths
 list.  For each item found, both a Filesys::POSIX::Path object, and an inode,
 respectively, are passed as the sole arguments to the callback.  With this
 mechanism, it is possible to retrieve path data from each item in every way
 currently provided by L<File::Find>, without retaining global state to do so.
 As a reference to the corresponding item's inode object is passed, there is no
-need to perform a $fs->stat() call to further inspect the item.
+need to perform a C<$fs-E<gt>stat> call to further inspect the item.
 
 When called with an $options argument, specified in the form of an anonymous
 HASH, the following flags (whose values are set nonzero) are honored:
