@@ -10,7 +10,7 @@ use Carp qw/confess/;
 
 =head1 NAME
 
-Filesys::POSIX::Userland::Tar
+Filesys::POSIX::Userland::Tar - Generate ustar archives from L<Filesys::POSIX>
 
 =head1 SYNOPSIS
 
@@ -34,8 +34,8 @@ Filesys::POSIX::Userland::Tar
 This module provides an implementation of the ustar standard on top of the
 virtual filesystem layer, a mechanism intended to take advantage of the many
 possible mapping and manipulation capabilities inherent in this mechanism.
-Internally, it uses the Filesys::POSIX::Userland::Find module to perform depth-
-last recursion to locate inodes for packaging.
+Internally, it uses the L<Filesys::POSIX::Userland::Find> module to perform
+depth- last recursion to locate inodes for packaging.
 
 As mentioned, archives are written in the ustar format, with pathnames of the
 extended maximum length of 256 characters, supporting file sizes up to 4GB.
@@ -142,7 +142,14 @@ sub _header {
     my %filename_parts = _split_filename($dest);
     my $header;
 
-    my $size = $inode->file ? $inode->{'size'} : 0;
+    my $size  = $inode->file ? $inode->{'size'} : 0;
+    my $major = 0;
+    my $minor = 0;
+
+    if ( $inode->char || $inode->block ) {
+        $major = $inode->major;
+        $minor = $inode->minor;
+    }
 
     $header .= _pad_string( $filename_parts{'suffix'}, 100 );
     $header .= _format_number( $inode->{'mode'} & $S_IPERM, 7,  8 );
@@ -164,8 +171,8 @@ sub _header {
     $header .= _pad_string( '00',    2 );
     $header .= "\x00" x 32;
     $header .= "\x00" x 32;
-    $header .= _format_number( 0, 7, 8 );
-    $header .= _format_number( 0, 7, 8 );
+    $header .= _format_number( $major, 7, 8 );
+    $header .= _format_number( $minor, 7, 8 );
     $header .= _pad_string( $filename_parts{'prefix'}, 155 );
 
     my $checksum = _checksum($header);
@@ -175,8 +182,8 @@ sub _header {
 }
 
 #
-# NOTE: I'm only using $inode->open() calls to save stat()s.  This is not
-# necessarily something that should be done by end user software.
+# NOTE: I'm only using $inode->open() calls to avoid having to call stat().
+# This is not necessarily something that should be done by end user software.
 #
 sub _write_file {
     my ( $fs, $handle, $dest, $inode ) = @_;
@@ -207,14 +214,14 @@ sub _archive {
     _write_file( $fs, $handle, $dest, $inode ) if $inode->file;
 }
 
-=item $fs->tar($handle, @items)
+=item C<$fs-E<gt>tar($handle, @items)>
 
-=item $fs->tar($handle, $opts, @items)
+=item C<$fs-E<gt>tar($handle, $opts, @items)>
 
 Locate files and directories in each path specified in the @items array,
 writing results to the I/O handle wrapper specified by $handle, an instance of
-Filesys::POSIX::IO::Handle.  When an anonymous HASH argument, $opts, is
-specified, the data is passed unmodified to Filesys::POSIX::Userland::Find.
+L<Filesys::POSIX::IO::Handle>.  When an anonymous HASH argument, $opts, is
+specified, the data is passed unmodified to L<Filesys::POSIX::Userland::Find>.
 In this way, for instance, the behavior of following symlinks can be specified.
 
 =cut
